# Globza

Python library to interact with the universal API service. 

## About the license

The license (free of charge subject to the 2 simple conditions) is specified in the file: LICENSE.txt

## Installation

To install Globza, run this command in your terminal:

```bash
pip install Globza

